package com.hungraim.ltc.account.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.account.service.AccountService;
import com.hungraim.ltc.pojo.entity.account.ChDisabAccounts;
import com.hungraim.ltc.pojo.entity.account.ChDisabDetailAccountsResp;
import com.hungraim.ltc.pojo.vo.account.*;
import com.hungraim.ltc.util.FileUtils;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.Date;
import java.util.List;

/**
 * 结算管理控制层
 */
@RestController
@RequestMapping("/api.account/account")
@AllArgsConstructor
@Slf4j
public class AccountController {

    private final AccountService accountService;

    /**
     * 添加或修改结算记录
     *
     * @return 返回状态
     */
    @PostMapping("/addOrUpdateAccount")
    public Result addOrUpdateAccount(AccountOperVo accountOperVo) {
     /*   if (null == accountOperVo.getSrvOrganId() || null == accountOperVo.getAccountsTime() || StringUtils.isBlank(accountOperVo.getTotalExpensesPayable()) || null == accountOperVo.getAccountsStatus()) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }*/
        Long accountsId = accountOperVo.getAccountsId();
        Date accountsTime = accountOperVo.getAccountsTime();
        Long srvOrganId = accountOperVo.getSrvOrganId();
        if (null == accountsId) {
            List<ChDisabAccounts> list = accountService.list(new LambdaQueryWrapper<ChDisabAccounts>().eq(ChDisabAccounts::getAccountsTime, accountsTime).eq(ChDisabAccounts::getSrvOrganId, srvOrganId));
            if (null != list && list.size() > 0) {
                return Result.failed("当前机构当月已存在结算数据");
            }
        }
        accountService.addOrUpdateAccount(accountOperVo);
        return Result.success();
    }

    /**
     * 查询结算信息列表
     *
     * @param srvOrganListReq 请求参数对象
     * @return 返回雷彪
     */
    @GetMapping("/searchSrvOrganList")
    public Result<Page<SrvOrganListResp>> searchSrvOrganList(SrvOrganListReq srvOrganListReq) {
        return Result.success(accountService.searchSrvOrganList(srvOrganListReq));
    }

    /**
     * 获取结算详情
     *
     * @param accountsId 结算id
     * @return 返回机构结算详情
     */
    @GetMapping("/srvOrganDetail")
    public Result<AccountOperVo> getSrvOrganDetail(Long accountsId) {
        if (null == accountsId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        return Result.success(accountService.getSrvOrganDetail(accountsId));
    }

    /**
     * 费用结算
     *
     * @return  返回机构结当月算详情
     */
    @GetMapping("/expenseSettlement")
    public Result<ExpenseVo> expenseSettlement(ExpenseSettlementReq req) throws ParseException {
        if (null == req.getSrvOrganId() || StringUtils.isBlank(req.getAccountsTime())) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (req.getPageNum() == null) {
            req.setPageNum(1);
        }
        if (req.getPageSize() == null) {
            req.setPageSize(10);
        }
        return Result.success(accountService.expenseSettlement(req));
    }




    @RequestMapping("/organAccountTaskExecute")
    public Result organAccountTaskExecute(AccountTaskReqVO accountTaskReqVO){
        List<AccountTaskExecuteReqVO> accountTaskExecuteReqVOS = accountTaskReqVO.getAccountTaskList();
        accountService.organAccountTaskExecute(accountTaskExecuteReqVOS);
       return Result.success();
    }


    @GetMapping("/getOtherPlace")
    public Result otherPlaceHandler(String programId){
        accountService.otherPlaceHandler(programId);
        return Result.success();
    }



    /**
     * 任务列表
     *
     * @param srvTaskReqVO 请求参数对象
     * @return 返回
     */
    @GetMapping("/getSrvTaskList")
    public Result<Page<SrvTaskRespVO>> getSrvTaskList(SrvTaskReqVO srvTaskReqVO) {
        return Result.success(accountService.getSrvTaskList(srvTaskReqVO));
    }


    /**
     * 查询机构结算列表
     *
     * @param srvOrganListReq 请求参数对象
     * @return 返回
     */
    @GetMapping("/searchSrvOrganAccountList")
    public Result<Page<SrvOrganAccountListResp>> searchSrvOrganAccountList(SrvOrganListReq srvOrganListReq) {
        return Result.success(accountService.searchSrvOrganAccountList(srvOrganListReq));
    }


    /**
     *  机构结算明细导出
     *
     */
    @GetMapping("/srvOrganAccountExport")
    public void srvOrganAccountExport(String accountsId,HttpServletResponse response){
        Workbook workbook = accountService.srvOrganAccountExport(accountsId);
        // 命名表格
        String fileName = "srvOrganAccount.xlsx";
        FileUtils.exportResponse(workbook,fileName,response);
    }









    /**
     * 查询机构结算信息列表明细
     *
     * @param id 结算id
     * @return
     */
    @GetMapping("/queryOrganAccountsDetail")
    public Result<List<ChDisabDetailAccountsResp>>   queryOrganAccountsDetail(String id) {
        List<ChDisabDetailAccountsResp> chAssessDetailAccounts = accountService.queryOrganAccountsDetail(id);
        return Result.success(chAssessDetailAccounts);
    }




    /**
     * 机构结算管理提交复核
     *
     * @param id 结算id
     * @return 返回雷彪
     */
    @PostMapping("/updatechDisabAccounts")
    public Result updateChDisabAccounts(int id) {
        int bl = accountService.updateChDisabAccounts(id);
        if(bl>0){
            return Result.success();
        }else{
            return Result.failed();
        }

    }


}


